@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Andrew Bettison <andrewb@zip.com.au>                          #
@@ -16,13 +14,15 @@
 # Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
 # Copyright 2016 Matt Babineau <babineaum@users.noreply.github.com>            #
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
-# Copyright 2017 Nicolas Agustín Torres <nicolastrres@gmail.com>              #
+# Copyright 2017 Nicolas Agustín Torres <nicolastrres@gmail.com>               #
 # Copyright 2017 Simon <spam@esemi.ru>                                         #
 # Copyright 2018 Shinichi TAMURA <shnch.tmr@gmail.com>                         #
 # Copyright 2018 Steve Kowalik <steven@wedontsleep.org>                        #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 per1234 <accounts@perglass.com>                               #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Nick Campbell <nicholas.j.campbell@gmail.com>                 #
+# Copyright 2020 Huan-Cheng Chang <changhc84@gmail.com>                        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -42,30 +42,33 @@
 #                                                                              #
 ################################################################################
 
-import urllib
 import datetime
+import urllib.parse
+
 import github.GithubObject
-import github.PaginatedList
-
-import github.Repository
-import github.IssueEvent
-import github.Label
-import github.NamedUser
-import github.Milestone
 import github.IssueComment
+import github.IssueEvent
 import github.IssuePullRequest
+import github.Label
+import github.Milestone
+import github.NamedUser
+import github.PaginatedList
 import github.Reaction
+import github.Repository
+import github.TimelineEvent
 
-import Consts
+from . import Consts
 
 
 class Issue(github.GithubObject.CompletableGithubObject):
     """
-    This class represents Issues. The reference can be found here https://developer.github.com/v3/issues/
+    This class represents Issues. The reference can be found here https://docs.github.com/en/rest/reference/issues
     """
 
     def __repr__(self):
-        return self.get__repr__({"number": self._number.value, "title": self._title.value})
+        return self.get__repr__(
+            {"number": self._number.value, "title": self._title.value}
+        )
 
     @property
     def assignee(self):
@@ -204,7 +207,11 @@ class Issue(github.GithubObject.CompletableGithubObject):
         if self._repository is github.GithubObject.NotSet:
             # The repository was not set automatically, so it must be looked up by url.
             repo_url = "/".join(self.url.split("/")[:-2])
-            self._repository = github.GithubObject._ValuedAttribute(github.Repository.Repository(self._requester, self._headers, {'url': repo_url}, completed=False))
+            self._repository = github.GithubObject._ValuedAttribute(
+                github.Repository.Repository(
+                    self._requester, self._headers, {"url": repo_url}, completed=False
+                )
+            )
         return self._repository.value
 
     @property
@@ -247,256 +254,369 @@ class Issue(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._user)
         return self._user.value
 
+    @property
+    def locked(self):
+        """
+        :type: bool
+        """
+        self._completeIfNotSet(self._locked)
+        return self._locked.value
+
+    @property
+    def active_lock_reason(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._active_lock_reason)
+        return self._active_lock_reason.value
+
     def as_pull_request(self):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number <http://developer.github.com/v3/pulls>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number} <http://docs.github.com/en/rest/reference/pulls>`_
         :rtype: :class:`github.PullRequest.PullRequest`
         """
         headers, data = self._requester.requestJsonAndCheck(
-            "GET",
-            "/pulls/".join(self.url.rsplit("/issues/", 1))
+            "GET", "/pulls/".join(self.url.rsplit("/issues/", 1))
+        )
+        return github.PullRequest.PullRequest(
+            self._requester, headers, data, completed=True
         )
-        return github.PullRequest.PullRequest(self._requester, headers, data, completed=True)
 
     def add_to_assignees(self, *assignees):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/assignees <https://developer.github.com/v3/issues/assignees>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/assignees <https://docs.github.com/en/rest/reference/issues#assignees>`_
         :param assignee: :class:`github.NamedUser.NamedUser` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.NamedUser.NamedUser, str, unicode)) for element in assignees), assignees
-        post_parameters = {"assignees": [assignee.login if isinstance(assignee, github.NamedUser.NamedUser) else assignee for assignee in assignees]}
+        assert all(
+            isinstance(element, (github.NamedUser.NamedUser, str))
+            for element in assignees
+        ), assignees
+        post_parameters = {
+            "assignees": [
+                assignee.login
+                if isinstance(assignee, github.NamedUser.NamedUser)
+                else assignee
+                for assignee in assignees
+            ]
+        }
         headers, data = self._requester.requestJsonAndCheck(
-            "POST",
-            self.url + "/assignees",
-            input=post_parameters
+            "POST", f"{self.url}/assignees", input=post_parameters
         )
         self._useAttributes(data)
 
     def add_to_labels(self, *labels):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/labels <http://docs.github.com/en/rest/reference/issues#labels>`_
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.Label.Label, str, unicode)) for element in labels), labels
-        post_parameters = [label.name if isinstance(label, github.Label.Label) else label for label in labels]
+        assert all(
+            isinstance(element, (github.Label.Label, str)) for element in labels
+        ), labels
+        post_parameters = [
+            label.name if isinstance(label, github.Label.Label) else label
+            for label in labels
+        ]
         headers, data = self._requester.requestJsonAndCheck(
-            "POST",
-            self.url + "/labels",
-            input=post_parameters
+            "POST", f"{self.url}/labels", input=post_parameters
         )
 
     def create_comment(self, body):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/comments <http://developer.github.com/v3/issues/comments>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/comments <http://docs.github.com/en/rest/reference/issues#comments>`_
         :param body: string
         :rtype: :class:`github.IssueComment.IssueComment`
         """
-        assert isinstance(body, (str, unicode)), body
+        assert isinstance(body, str), body
         post_parameters = {
             "body": body,
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "POST",
-            self.url + "/comments",
-            input=post_parameters
+            "POST", f"{self.url}/comments", input=post_parameters
+        )
+        return github.IssueComment.IssueComment(
+            self._requester, headers, data, completed=True
         )
-        return github.IssueComment.IssueComment(self._requester, headers, data, completed=True)
 
     def delete_labels(self):
         """
-        :calls: `DELETE /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{number}/labels <http://docs.github.com/en/rest/reference/issues#labels>`_
         :rtype: None
         """
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE",
-            self.url + "/labels"
+            "DELETE", f"{self.url}/labels"
         )
 
-    def edit(self, title=github.GithubObject.NotSet, body=github.GithubObject.NotSet, assignee=github.GithubObject.NotSet, state=github.GithubObject.NotSet, milestone=github.GithubObject.NotSet, labels=github.GithubObject.NotSet, assignees=github.GithubObject.NotSet):
+    def edit(
+        self,
+        title=github.GithubObject.NotSet,
+        body=github.GithubObject.NotSet,
+        assignee=github.GithubObject.NotSet,
+        state=github.GithubObject.NotSet,
+        milestone=github.GithubObject.NotSet,
+        labels=github.GithubObject.NotSet,
+        assignees=github.GithubObject.NotSet,
+    ):
         """
-        :calls: `PATCH /repos/:owner/:repo/issues/:number <http://developer.github.com/v3/issues>`_
+        :calls: `PATCH /repos/{owner}/{repo}/issues/{number} <http://docs.github.com/en/rest/reference/issues>`_
         :param title: string
         :param body: string
         :param assignee: string or :class:`github.NamedUser.NamedUser` or None
-        :param assignees: list (of string or :class:`github.NamedUser.NamedUser`)
+        :param assignees: list of string or :class:`github.NamedUser.NamedUser`
         :param state: string
         :param milestone: :class:`github.Milestone.Milestone` or None
         :param labels: list of string
         :rtype: None
         """
-        assert title is github.GithubObject.NotSet or isinstance(title, (str, unicode)), title
-        assert body is github.GithubObject.NotSet or isinstance(body, (str, unicode)), body
-        assert assignee is github.GithubObject.NotSet or assignee is None or isinstance(assignee, github.NamedUser.NamedUser) or isinstance(assignee, (str, unicode)), assignee
-        assert assignees is github.GithubObject.NotSet or all(isinstance(element, github.NamedUser.NamedUser) or isinstance(element, (str, unicode)) for element in assignees), assignees
-        assert state is github.GithubObject.NotSet or isinstance(state, (str, unicode)), state
-        assert milestone is github.GithubObject.NotSet or milestone is None or isinstance(milestone, github.Milestone.Milestone), milestone
-        assert labels is github.GithubObject.NotSet or all(isinstance(element, (str, unicode)) for element in labels), labels
+        assert title is github.GithubObject.NotSet or isinstance(title, str), title
+        assert body is github.GithubObject.NotSet or isinstance(body, str), body
+        assert (
+            assignee is github.GithubObject.NotSet
+            or assignee is None
+            or isinstance(assignee, github.NamedUser.NamedUser)
+            or isinstance(assignee, str)
+        ), assignee
+        assert assignees is github.GithubObject.NotSet or all(
+            isinstance(element, github.NamedUser.NamedUser) or isinstance(element, str)
+            for element in assignees
+        ), assignees
+        assert state is github.GithubObject.NotSet or isinstance(state, str), state
+        assert (
+            milestone is github.GithubObject.NotSet
+            or milestone is None
+            or isinstance(milestone, github.Milestone.Milestone)
+        ), milestone
+        assert labels is github.GithubObject.NotSet or all(
+            isinstance(element, str) for element in labels
+        ), labels
         post_parameters = dict()
         if title is not github.GithubObject.NotSet:
             post_parameters["title"] = title
         if body is not github.GithubObject.NotSet:
             post_parameters["body"] = body
         if assignee is not github.GithubObject.NotSet:
-            if isinstance(assignee, (str, unicode)):
+            if isinstance(assignee, str):
                 post_parameters["assignee"] = assignee
             else:
-                post_parameters["assignee"] = assignee._identity if assignee else ''
+                post_parameters["assignee"] = assignee._identity if assignee else ""
         if assignees is not github.GithubObject.NotSet:
-            post_parameters["assignees"] = [element._identity if isinstance(element, github.NamedUser.NamedUser) else element for element in assignees]
+            post_parameters["assignees"] = [
+                element._identity
+                if isinstance(element, github.NamedUser.NamedUser)
+                else element
+                for element in assignees
+            ]
         if state is not github.GithubObject.NotSet:
             post_parameters["state"] = state
         if milestone is not github.GithubObject.NotSet:
-            post_parameters["milestone"] = milestone._identity if milestone else ''
+            post_parameters["milestone"] = milestone._identity if milestone else ""
         if labels is not github.GithubObject.NotSet:
             post_parameters["labels"] = labels
         headers, data = self._requester.requestJsonAndCheck(
-            "PATCH",
-            self.url,
-            input=post_parameters
+            "PATCH", self.url, input=post_parameters
         )
         self._useAttributes(data)
 
+    def lock(self, lock_reason):
+        """
+        :calls: `PUT /repos/{owner}/{repo}/issues/{issue_number}/lock <https://docs.github.com/en/rest/reference/issues>`_
+        :param lock_reason: string
+        :rtype: None
+        """
+        assert isinstance(lock_reason, str), lock_reason
+        put_parameters = dict()
+        put_parameters["lock_reason"] = lock_reason
+        headers, data = self._requester.requestJsonAndCheck(
+            "PUT",
+            f"{self.url}/lock",
+            input=put_parameters,
+            headers={"Accept": Consts.mediaTypeLockReasonPreview},
+        )
+
+    def unlock(self):
+        """
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{issue_number}/lock <https://docs.github.com/en/rest/reference/issues>`_
+        :rtype: None
+        """
+        headers, data = self._requester.requestJsonAndCheck(
+            "DELETE", f"{self.url}/lock"
+        )
+
     def get_comment(self, id):
         """
-        :calls: `GET /repos/:owner/:repo/issues/comments/:id <http://developer.github.com/v3/issues/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/comments/{id} <http://docs.github.com/en/rest/reference/issues#comments>`_
         :param id: integer
         :rtype: :class:`github.IssueComment.IssueComment`
         """
-        assert isinstance(id, (int, long)), id
+        assert isinstance(id, int), id
         headers, data = self._requester.requestJsonAndCheck(
-            "GET",
-            self._parentUrl(self.url) + "/comments/" + str(id)
+            "GET", f"{self._parentUrl(self.url)}/comments/{id}"
+        )
+        return github.IssueComment.IssueComment(
+            self._requester, headers, data, completed=True
         )
-        return github.IssueComment.IssueComment(self._requester, headers, data, completed=True)
 
     def get_comments(self, since=github.GithubObject.NotSet):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number/comments <http://developer.github.com/v3/issues/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{number}/comments <http://docs.github.com/en/rest/reference/issues#comments>`_
         :param since: datetime.datetime format YYYY-MM-DDTHH:MM:SSZ
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.IssueComment.IssueComment`
         """
-        assert since is github.GithubObject.NotSet or isinstance(since, datetime.datetime), since
+        assert since is github.GithubObject.NotSet or isinstance(
+            since, datetime.datetime
+        ), since
         url_parameters = dict()
         if since is not github.GithubObject.NotSet:
             url_parameters["since"] = since.strftime("%Y-%m-%dT%H:%M:%SZ")
         return github.PaginatedList.PaginatedList(
             github.IssueComment.IssueComment,
             self._requester,
-            self.url + "/comments",
-            url_parameters
+            f"{self.url}/comments",
+            url_parameters,
         )
 
     def get_events(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:issue_number/events <http://developer.github.com/v3/issues/events>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{issue_number}/events <http://docs.github.com/en/rest/reference/issues#events>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.IssueEvent.IssueEvent`
         """
         return github.PaginatedList.PaginatedList(
             github.IssueEvent.IssueEvent,
             self._requester,
-            self.url + "/events",
+            f"{self.url}/events",
             None,
-            headers={'Accept': Consts.mediaTypeLockReasonPreview}
+            headers={"Accept": Consts.mediaTypeLockReasonPreview},
         )
 
     def get_labels(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{number}/labels <http://docs.github.com/en/rest/reference/issues#labels>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Label.Label`
         """
         return github.PaginatedList.PaginatedList(
-            github.Label.Label,
-            self._requester,
-            self.url + "/labels",
-            None
+            github.Label.Label, self._requester, f"{self.url}/labels", None
         )
 
     def remove_from_assignees(self, *assignees):
         """
-        :calls: `DELETE /repos/:owner/:repo/issues/:number/assignees <https://developer.github.com/v3/issues/assignees>`_
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{number}/assignees <https://docs.github.com/en/rest/reference/issues#assignees>`_
         :param assignee: :class:`github.NamedUser.NamedUser` or string
         :rtype: None
         """
-        assert all(isinstance(element, (github.NamedUser.NamedUser, str, unicode)) for element in assignees), assignees
-        post_parameters = {"assignees": [assignee.login if isinstance(assignee, github.NamedUser.NamedUser) else assignee for assignee in assignees]}
+        assert all(
+            isinstance(element, (github.NamedUser.NamedUser, str))
+            for element in assignees
+        ), assignees
+        post_parameters = {
+            "assignees": [
+                assignee.login
+                if isinstance(assignee, github.NamedUser.NamedUser)
+                else assignee
+                for assignee in assignees
+            ]
+        }
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE",
-            self.url + "/assignees",
-            input=post_parameters
+            "DELETE", f"{self.url}/assignees", input=post_parameters
         )
         self._useAttributes(data)
 
     def remove_from_labels(self, label):
         """
-        :calls: `DELETE /repos/:owner/:repo/issues/:number/labels/:name <http://developer.github.com/v3/issues/labels>`_
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{number}/labels/{name} <http://docs.github.com/en/rest/reference/issues#labels>`_
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
-        assert isinstance(label, (github.Label.Label, str, unicode)), label
+        assert isinstance(label, (github.Label.Label, str)), label
         if isinstance(label, github.Label.Label):
             label = label._identity
         else:
-            label = urllib.quote(label)
+            label = urllib.parse.quote(label)
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE",
-            self.url + "/labels/" + label
+            "DELETE", f"{self.url}/labels/{label}"
         )
 
     def set_labels(self, *labels):
         """
-        :calls: `PUT /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `PUT /repos/{owner}/{repo}/issues/{number}/labels <http://docs.github.com/en/rest/reference/issues#labels>`_
         :param labels: list of :class:`github.Label.Label` or strings
         :rtype: None
         """
-        assert all(isinstance(element, (github.Label.Label, str, unicode)) for element in labels), labels
-        post_parameters = [label.name if isinstance(label, github.Label.Label) else label for label in labels]
+        assert all(
+            isinstance(element, (github.Label.Label, str)) for element in labels
+        ), labels
+        post_parameters = [
+            label.name if isinstance(label, github.Label.Label) else label
+            for label in labels
+        ]
         headers, data = self._requester.requestJsonAndCheck(
-            "PUT",
-            self.url + "/labels",
-            input=post_parameters
+            "PUT", f"{self.url}/labels", input=post_parameters
         )
 
     def get_reactions(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number/reactions <https://developer.github.com/v3/reactions/#list-reactions-for-an-issue>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{number}/reactions <https://docs.github.com/en/rest/reference/reactions#list-reactions-for-an-issue>`_
         :return: :class: :class:`github.PaginatedList.PaginatedList` of :class:`github.Reaction.Reaction`
         """
         return github.PaginatedList.PaginatedList(
             github.Reaction.Reaction,
             self._requester,
-            self.url + "/reactions",
+            f"{self.url}/reactions",
             None,
-            headers={'Accept': Consts.mediaTypeReactionsPreview}
+            headers={"Accept": Consts.mediaTypeReactionsPreview},
         )
 
     def create_reaction(self, reaction_type):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/reactions <https://developer.github.com/v3/reactions>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/reactions <https://docs.github.com/en/rest/reference/reactions>`_
         :param reaction_type: string
         :rtype: :class:`github.Reaction.Reaction`
         """
-        assert isinstance(reaction_type, (str, unicode)), "reaction type should be a string"
-        assert reaction_type in ["+1", "-1", "laugh", "confused", "heart", "hooray"], \
-            "Invalid reaction type (https://developer.github.com/v3/reactions/#reaction-types)"
-
+        assert isinstance(reaction_type, str), reaction_type
         post_parameters = {
             "content": reaction_type,
         }
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
-            self.url + "/reactions",
+            f"{self.url}/reactions",
             input=post_parameters,
-            headers={'Accept': Consts.mediaTypeReactionsPreview}
+            headers={"Accept": Consts.mediaTypeReactionsPreview},
         )
         return github.Reaction.Reaction(self._requester, headers, data, completed=True)
 
+    def delete_reaction(self, reaction_id):
+        """
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{issue_number}/reactions/{reaction_id} <https://docs.github.com/en/rest/reference/reactions#delete-an-issue-reaction>`_
+        :param reaction_id: integer
+        :rtype: bool
+        """
+        assert isinstance(reaction_id, int), reaction_id
+        status, _, _ = self._requester.requestJson(
+            "DELETE",
+            f"{self.url}/reactions/{reaction_id}",
+            headers={"Accept": Consts.mediaTypeReactionsPreview},
+        )
+        return status == 204
+
+    def get_timeline(self):
+        """
+        :calls: `GET /repos/{owner}/{repo}/issues/{number}/timeline <https://docs.github.com/en/rest/reference/issues/timeline#list-events-for-an-issue>`_
+        :return: :class: :class:`github.PaginatedList.PaginatedList` of :class:`github.TimelineEvent.TimelineEvent`
+        """
+        return github.PaginatedList.PaginatedList(
+            github.TimelineEvent.TimelineEvent,
+            self._requester,
+            f"{self.url}/timeline",
+            None,
+            headers={"Accept": Consts.issueTimelineEventsPreview},
+        )
+
     @property
     def _identity(self):
         return self.number
 
     def _initAttributes(self):
+        self._active_lock_reason = github.GithubObject.NotSet
         self._assignee = github.GithubObject.NotSet
         self._assignees = github.GithubObject.NotSet
         self._body = github.GithubObject.NotSet
@@ -510,6 +630,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         self._id = github.GithubObject.NotSet
         self._labels = github.GithubObject.NotSet
         self._labels_url = github.GithubObject.NotSet
+        self._locked = github.GithubObject.NotSet
         self._milestone = github.GithubObject.NotSet
         self._number = github.GithubObject.NotSet
         self._pull_request = github.GithubObject.NotSet
@@ -521,21 +642,35 @@ class Issue(github.GithubObject.CompletableGithubObject):
         self._user = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
+        if "active_lock_reason" in attributes:  # pragma no branch
+            self._active_lock_reason = self._makeStringAttribute(
+                attributes["active_lock_reason"]
+            )
         if "assignee" in attributes:  # pragma no branch
-            self._assignee = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["assignee"])
+            self._assignee = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["assignee"]
+            )
         if "assignees" in attributes:  # pragma no branch
-            self._assignees = self._makeListOfClassesAttribute(github.NamedUser.NamedUser, attributes["assignees"])
+            self._assignees = self._makeListOfClassesAttribute(
+                github.NamedUser.NamedUser, attributes["assignees"]
+            )
         elif "assignee" in attributes:
             if attributes["assignee"] is not None:
-                self._assignees = self._makeListOfClassesAttribute(github.NamedUser.NamedUser, [attributes["assignee"]])
+                self._assignees = self._makeListOfClassesAttribute(
+                    github.NamedUser.NamedUser, [attributes["assignee"]]
+                )
             else:
-                self._assignees = self._makeListOfClassesAttribute(github.NamedUser.NamedUser, [])
+                self._assignees = self._makeListOfClassesAttribute(
+                    github.NamedUser.NamedUser, []
+                )
         if "body" in attributes:  # pragma no branch
             self._body = self._makeStringAttribute(attributes["body"])
         if "closed_at" in attributes:  # pragma no branch
             self._closed_at = self._makeDatetimeAttribute(attributes["closed_at"])
         if "closed_by" in attributes:  # pragma no branch
-            self._closed_by = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["closed_by"])
+            self._closed_by = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["closed_by"]
+            )
         if "comments" in attributes:  # pragma no branch
             self._comments = self._makeIntAttribute(attributes["comments"])
         if "comments_url" in attributes:  # pragma no branch
@@ -549,17 +684,27 @@ class Issue(github.GithubObject.CompletableGithubObject):
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
         if "labels" in attributes:  # pragma no branch
-            self._labels = self._makeListOfClassesAttribute(github.Label.Label, attributes["labels"])
+            self._labels = self._makeListOfClassesAttribute(
+                github.Label.Label, attributes["labels"]
+            )
         if "labels_url" in attributes:  # pragma no branch
             self._labels_url = self._makeStringAttribute(attributes["labels_url"])
+        if "locked" in attributes:  # pragma no branch
+            self._locked = self._makeBoolAttribute(attributes["locked"])
         if "milestone" in attributes:  # pragma no branch
-            self._milestone = self._makeClassAttribute(github.Milestone.Milestone, attributes["milestone"])
+            self._milestone = self._makeClassAttribute(
+                github.Milestone.Milestone, attributes["milestone"]
+            )
         if "number" in attributes:  # pragma no branch
             self._number = self._makeIntAttribute(attributes["number"])
         if "pull_request" in attributes:  # pragma no branch
-            self._pull_request = self._makeClassAttribute(github.IssuePullRequest.IssuePullRequest, attributes["pull_request"])
+            self._pull_request = self._makeClassAttribute(
+                github.IssuePullRequest.IssuePullRequest, attributes["pull_request"]
+            )
         if "repository" in attributes:  # pragma no branch
-            self._repository = self._makeClassAttribute(github.Repository.Repository, attributes["repository"])
+            self._repository = self._makeClassAttribute(
+                github.Repository.Repository, attributes["repository"]
+            )
         if "state" in attributes:  # pragma no branch
             self._state = self._makeStringAttribute(attributes["state"])
         if "title" in attributes:  # pragma no branch
@@ -569,4 +714,6 @@ class Issue(github.GithubObject.CompletableGithubObject):
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
         if "user" in attributes:  # pragma no branch
-            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
+            self._user = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["user"]
+            )
