@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
@@ -31,16 +29,16 @@
 #                                                                              #
 ################################################################################
 
-import urllib
+import urllib.parse
 
 import github.GithubObject
 
-import Consts
+from . import Consts
 
 
 class Label(github.GithubObject.CompletableGithubObject):
     """
-    This class represents Labels. The reference can be found here http://developer.github.com/v3/issues/labels/
+    This class represents Labels. The reference can be found here http://docs.github.com/en/rest/reference/issues#labels
     """
 
     def __repr__(self):
@@ -80,27 +78,26 @@ class Label(github.GithubObject.CompletableGithubObject):
 
     def delete(self):
         """
-        :calls: `DELETE /repos/:owner/:repo/labels/:name <http://developer.github.com/v3/issues/labels>`_
+        :calls: `DELETE /repos/{owner}/{repo}/labels/{name} <http://docs.github.com/en/rest/reference/issues#labels>`_
         :rtype: None
         """
-        headers, data = self._requester.requestJsonAndCheck(
-            "DELETE",
-            self.url
-        )
+        headers, data = self._requester.requestJsonAndCheck("DELETE", self.url)
 
     def edit(self, name, color, description=github.GithubObject.NotSet):
         """
-        :calls: `PATCH /repos/:owner/:repo/labels/:name <http://developer.github.com/v3/issues/labels>`_
+        :calls: `PATCH /repos/{owner}/{repo}/labels/{name} <http://docs.github.com/en/rest/reference/issues#labels>`_
         :param name: string
         :param color: string
         :param description: string
         :rtype: None
         """
-        assert isinstance(name, (str, unicode)), name
-        assert isinstance(color, (str, unicode)), color
-        assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
+        assert isinstance(name, str), name
+        assert isinstance(color, str), color
+        assert description is github.GithubObject.NotSet or isinstance(
+            description, str
+        ), description
         post_parameters = {
-            "name": name,
+            "new_name": name,
             "color": color,
         }
         if description is not github.GithubObject.NotSet:
@@ -109,13 +106,13 @@ class Label(github.GithubObject.CompletableGithubObject):
             "PATCH",
             self.url,
             input=post_parameters,
-            headers={'Accept': Consts.mediaTypeLabelDescriptionSearchPreview}
+            headers={"Accept": Consts.mediaTypeLabelDescriptionSearchPreview},
         )
         self._useAttributes(data)
 
     @property
     def _identity(self):
-        return urllib.quote(self.name)
+        return urllib.parse.quote(self.name)
 
     def _initAttributes(self):
         self._color = github.GithubObject.NotSet
